@@ -17,7 +17,7 @@ from .. import (
     error as error_module,
     log,
 )
-from . import backend_arguments, commands, remote_logging, start, validate_models
+from . import backend_arguments, commands, start, validate_models
 
 LOG: logging.Logger = logging.getLogger(__name__)
 
@@ -38,6 +38,8 @@ class Arguments:
     maximum_tito_depth: Optional[int] = None
     maximum_trace_length: Optional[int] = None
     no_verify: bool = False
+    no_verify_models: bool = False
+    no_verify_dsl: bool = False
     repository_root: Optional[str] = None
     rule_filter: Optional[Sequence[int]] = None
     save_results_to: Optional[str] = None
@@ -79,6 +81,8 @@ class Arguments:
                 else {"maximum_trace_length": maximum_trace_length}
             ),
             "no_verify": self.no_verify,
+            "no_verify_models": self.no_verify_models,
+            "no_verify_dsl": self.no_verify_dsl,
             **({} if repository_root is None else {"repository_root": repository_root}),
             **({} if rule_filter is None else {"rule_filter": rule_filter}),
             **({} if save_results_to is None else {"save_results_to": save_results_to}),
@@ -136,9 +140,7 @@ def create_analyze_arguments(
             checked_directory_allowlist=backend_arguments.get_checked_directory_allowlist(
                 configuration, source_paths
             ),
-            checked_directory_blocklist=(
-                configuration.get_existent_ignore_all_errors_paths()
-            ),
+            checked_directory_blocklist=(configuration.ignore_all_errors),
             debug=analyze_arguments.debug,
             excludes=configuration.excludes,
             extensions=configuration.get_valid_extension_suffixes(),
@@ -162,6 +164,8 @@ def create_analyze_arguments(
         maximum_tito_depth=analyze_arguments.maximum_tito_depth,
         maximum_trace_length=analyze_arguments.maximum_trace_length,
         no_verify=analyze_arguments.no_verify,
+        no_verify_models=analyze_arguments.no_verify_models,
+        no_verify_dsl=analyze_arguments.no_verify_dsl,
         repository_root=repository_root,
         rule_filter=None if len(rule) == 0 else rule,
         save_results_to=analyze_arguments.save_results_to,
@@ -210,6 +214,7 @@ def _run_analyze_command(
                 stdout=subprocess.PIPE,
                 stderr=log_file.file,
                 universal_newlines=True,
+                errors="replace",
             )
             return_code = result.returncode
 
@@ -268,14 +273,8 @@ def run_analyze(
             )
 
 
-@remote_logging.log_usage(command_name="analyze")
 def run(
     configuration: configuration_module.Configuration,
     analyze_arguments: command_arguments.AnalyzeArguments,
 ) -> commands.ExitCode:
-    try:
-        return run_analyze(configuration, analyze_arguments)
-    except Exception as error:
-        raise commands.ClientException(
-            f"Exception occurred during pyre analyze: {error}"
-        ) from error
+    return run_analyze(configuration, analyze_arguments)
