@@ -12,7 +12,7 @@ from pathlib import Path
 from typing import Any, Dict, Iterator, List, Sequence
 
 from .. import command_arguments, configuration as configuration_module, error
-from . import backend_arguments, commands, incremental, remote_logging, start
+from . import backend_arguments, commands, incremental, start
 
 
 LOG: logging.Logger = logging.getLogger(__name__)
@@ -87,9 +87,7 @@ def create_check_arguments(
             checked_directory_allowlist=backend_arguments.get_checked_directory_allowlist(
                 configuration, source_paths
             ),
-            checked_directory_blocklist=(
-                configuration.get_existent_ignore_all_errors_paths()
-            ),
+            checked_directory_blocklist=(configuration.ignore_all_errors),
             debug=check_arguments.debug,
             excludes=configuration.excludes,
             extensions=configuration.get_valid_extension_suffixes(),
@@ -162,6 +160,7 @@ def _run_check_command(command: Sequence[str], output: str) -> commands.ExitCode
                 stdout=subprocess.PIPE,
                 stderr=log_file.file,
                 universal_newlines=True,
+                errors="replace",
             )
             return_code = result.returncode
 
@@ -208,14 +207,8 @@ def run_check(
             )
 
 
-@remote_logging.log_usage(command_name="check")
 def run(
     configuration: configuration_module.Configuration,
     check_arguments: command_arguments.CheckArguments,
 ) -> commands.ExitCode:
-    try:
-        return run_check(configuration, check_arguments)
-    except Exception as error:
-        raise commands.ClientException(
-            f"Exception occurred during Pyre check: {error}"
-        ) from error
+    return run_check(configuration, check_arguments)
