@@ -14,7 +14,6 @@ import re
 import shutil
 import subprocess
 import sys
-import traceback
 from pathlib import Path
 from typing import Any, Dict, Iterator, List, Optional, Sequence, Set, TypeVar, Union
 
@@ -24,7 +23,7 @@ from libcst.codemod import CodemodContext
 
 from .. import command_arguments, configuration as configuration_module, log
 from ..libcst_vendored_visitors import ApplyTypeAnnotationsVisitor
-from . import backend_arguments, commands, remote_logging, start
+from . import backend_arguments, commands, start
 
 LOG: logging.Logger = logging.getLogger(__name__)
 
@@ -37,14 +36,11 @@ class Arguments:
     """
 
     base_arguments: backend_arguments.BaseArguments
-
-    ignore_infer: Sequence[str] = dataclasses.field(default_factory=list)
     paths_to_modify: Optional[Set[Path]] = None
 
     def serialize(self) -> Dict[str, Any]:
         return {
             **self.base_arguments.serialize(),
-            "ignore_infer": self.ignore_infer,
             **(
                 {}
                 if self.paths_to_modify is None
@@ -746,9 +742,7 @@ def create_infer_arguments(
             checked_directory_allowlist=backend_arguments.get_checked_directory_allowlist(
                 configuration, source_paths
             ),
-            checked_directory_blocklist=(
-                configuration.get_existent_ignore_all_errors_paths()
-            ),
+            checked_directory_blocklist=(configuration.ignore_all_errors),
             debug=infer_arguments.debug_infer,
             excludes=configuration.excludes,
             extensions=configuration.get_valid_extension_suffixes(),
@@ -763,7 +757,6 @@ def create_infer_arguments(
             search_paths=configuration.expand_and_get_existent_search_paths(),
             source_paths=source_paths,
         ),
-        ignore_infer=configuration.get_existent_ignore_infer_paths(),
         paths_to_modify=infer_arguments.paths_to_modify,
     )
 
@@ -811,6 +804,7 @@ def _run_infer_command_get_output(command: Sequence[str]) -> str:
                 stdout=subprocess.PIPE,
                 stderr=log_file.file,
                 universal_newlines=True,
+                errors="replace",
             )
             return_code = result.returncode
 
@@ -968,7 +962,7 @@ def _annotate_in_place(
             pass
 
 
-def run_infer(
+def run(
     configuration: configuration_module.Configuration,
     infer_arguments: command_arguments.InferArguments,
 ) -> commands.ExitCode:
@@ -988,6 +982,7 @@ def run_infer(
         dequalify=infer_arguments.dequalify,
         quote_annotations=infer_arguments.quote_annotations,
         simple_annotations=infer_arguments.simple_annotations,
+        debug_infer=infer_arguments.debug_infer,
     )
 
     if infer_arguments.annotate_from_existing_stubs:
@@ -1025,19 +1020,3 @@ def run_infer(
                     number_of_workers=configuration.get_number_of_workers(),
                 )
     return commands.ExitCode.SUCCESS
-
-
-@remote_logging.log_usage(command_name="infer")
-def run(
-    configuration: configuration_module.Configuration,
-    infer_arguments: command_arguments.InferArguments,
-) -> commands.ExitCode:
-    try:
-        return run_infer(configuration, infer_arguments)
-    except commands.ClientException:
-        raise
-    except Exception as error:
-        traceback.print_exc(file=sys.stderr)
-        raise commands.ClientException(
-            f"Exception occurred during Pyre infer: {error}"
-        ) from error
