@@ -31,14 +31,7 @@ from .. import (
     find_directories,
     log,
 )
-from . import (
-    backend_arguments,
-    commands,
-    remote_logging,
-    server_connection,
-    server_event,
-    stop,
-)
+from . import backend_arguments, commands, server_connection, server_event, stop
 
 
 LOG: logging.Logger = logging.getLogger(__name__)
@@ -145,9 +138,7 @@ class Arguments:
             "socket_path": str(
                 server_connection.get_default_socket_path(
                     Path(self.base_arguments.global_root),
-                    Path(self.base_arguments.relative_local_root)
-                    if self.base_arguments.relative_local_root
-                    else None,
+                    self.base_arguments.relative_local_root,
                 )
             ),
             "show_error_traces": self.show_error_traces,
@@ -288,9 +279,7 @@ def create_server_arguments(
             checked_directory_allowlist=backend_arguments.get_checked_directory_allowlist(
                 configuration, source_paths
             ),
-            checked_directory_blocklist=(
-                configuration.get_existent_ignore_all_errors_paths()
-            ),
+            checked_directory_blocklist=(configuration.ignore_all_errors),
             debug=start_arguments.debug,
             excludes=configuration.excludes,
             extensions=configuration.get_valid_extension_suffixes(),
@@ -477,10 +466,7 @@ def run_start(
             return _run_in_foreground(server_command, server_environment)
         else:
             socket_path = server_connection.get_default_socket_path(
-                Path(configuration.project_root),
-                Path(configuration.relative_local_root)
-                if configuration.relative_local_root
-                else None,
+                Path(configuration.project_root), configuration.relative_local_root
             )
             return _run_in_background(
                 server_command,
@@ -493,7 +479,6 @@ def run_start(
             )
 
 
-@remote_logging.log_usage(command_name="start")
 def run(
     configuration: configuration_module.Configuration,
     start_arguments: command_arguments.StartArguments,
