@@ -8,6 +8,8 @@ import logging
 from pathlib import Path
 from typing import Dict, List, Optional
 
+from pyre_extensions import override
+
 from typing_extensions import Final
 
 from ..configuration import Configuration
@@ -58,8 +60,6 @@ class ConsolidateNestedConfigurations(ErrorSuppressingCommand):
         )
 
     @classmethod
-    # pyre-fixme[40]: Non-static method `add_arguments` cannot override a static
-    #  method defined in `ErrorSuppressingCommand`.
     def add_arguments(cls, parser: argparse.ArgumentParser) -> None:
         super(ConsolidateNestedConfigurations, cls).add_arguments(parser)
         parser.set_defaults(command=cls.from_arguments)
@@ -95,6 +95,7 @@ class ConsolidateNestedConfigurations(ErrorSuppressingCommand):
                 nested_configurations[configuration] = []
         return nested_configurations
 
+    @override
     def run(self) -> None:
         subdirectory = self._subdirectory
         subdirectory = Path(subdirectory) if subdirectory else Path.cwd()
