@@ -9,6 +9,8 @@ import subprocess
 from pathlib import Path
 from typing import Optional
 
+from pyre_extensions import override
+
 from .. import UserError
 from ..configuration import Configuration
 from ..filesystem import path_exists
@@ -40,8 +42,6 @@ class FixConfiguration(ErrorSuppressingCommand):
         )
 
     @classmethod
-    # pyre-fixme[40]: Non-static method `add_arguments` cannot override a static
-    #  method defined in `ErrorSuppressingCommand`.
     def add_arguments(cls, parser: argparse.ArgumentParser) -> None:
         super(FixConfiguration, cls).add_arguments(parser)
         parser.set_defaults(command=cls.from_arguments)
@@ -111,6 +111,7 @@ class FixConfiguration(ErrorSuppressingCommand):
             reviewers=["pyre", "sentinel"],
         )
 
+    @override
     def run(self) -> None:
         self._remove_bad_targets()
         self._consolidate_nested()
