@@ -7,12 +7,13 @@ import argparse
 import logging
 from pathlib import Path
 
+from pyre_extensions import override
+
 from ..configuration import Configuration
 from ..filesystem import path_exists
 from ..repository import Repository
 from .command import CommandArguments, ErrorSource, ErrorSuppressingCommand
 
-
 LOG: logging.Logger = logging.getLogger(__name__)
 
 
@@ -48,8 +49,6 @@ class FixmeSingle(ErrorSuppressingCommand):
         )
 
     @classmethod
-    # pyre-fixme[40]: Non-static method `add_arguments` cannot override a static
-    #  method defined in `ErrorSuppressingCommand`.
     def add_arguments(cls, parser: argparse.ArgumentParser) -> None:
         super(FixmeSingle, cls).add_arguments(parser)
         parser.set_defaults(command=cls.from_arguments)
@@ -76,6 +75,7 @@ class FixmeSingle(ErrorSuppressingCommand):
             help="Ignore all errors if fixme count exceeds threshold.",
         )
 
+    @override
     def run(self) -> None:
         project_configuration = Configuration.find_project_configuration()
         configuration_path = self._path / ".pyre_configuration.local"
