@@ -45,10 +45,10 @@ class Configuration:
         self.use_buck_source_database: Optional[bool] = json_contents.get(
             "use_buck_source_database"
         )
-        self.use_command_v2: Optional[bool] = json_contents.get("use_command_v2")
         self.ignore_all_errors: Optional[List[str]] = json_contents.get(
             "ignore_all_errors"
         )
+        self.use_buck2: Optional[bool] = json_contents.get("use_buck2")
 
     def get_contents(self) -> Dict[str, Any]:
         """Assumption: The field names in this class match the key names in
@@ -69,7 +69,7 @@ class Configuration:
         update_contents("strict")
         update_contents("use_buck_builder")
         update_contents("use_buck_source_database")
-        update_contents("use_command_v2")
+        update_contents("use_buck2")
         return contents
 
     @staticmethod
@@ -162,8 +162,9 @@ class Configuration:
         self.use_buck_builder = True
         self.use_buck_source_database = True
 
-    def enable_new_server(self) -> None:
-        self.use_command_v2 = True
+    def set_use_buck1_if_possible(self) -> None:
+        if self.use_buck2 is None:
+            self.use_buck2 = False
 
     def add_strict(self) -> None:
         if self.strict:
