@@ -13,10 +13,9 @@ from logging import Logger
 from . import UserError
 from .ast import UnstableAST
 from .commands.codemods import (
-    EnableNewServer,
-    EnableSourceDatabaseBuckBuilder,
     MissingGlobalAnnotations,
     MissingOverrideReturnAnnotations,
+    SetUseBuck1,
 )
 from .commands.consolidate_nested_configurations import ConsolidateNestedConfigurations
 from .commands.expand_target_coverage import ExpandTargetCoverage
@@ -103,17 +102,12 @@ def run(repository: Repository) -> None:
     fix_configuration = commands.add_parser("fix-configuration")
     FixConfiguration.add_arguments(fix_configuration)
 
-    enable_source_database_buck_builder = commands.add_parser(
-        "enable-source-database-buck-builder"
-    )
-    EnableSourceDatabaseBuckBuilder.add_arguments(enable_source_database_buck_builder)
+    set_use_buck1 = commands.add_parser("set-use-buck1")
+    SetUseBuck1.add_arguments(set_use_buck1)
 
     support_sqlalchemy = commands.add_parser("support-sqlalchemy")
     SupportSqlalchemy.add_arguments(support_sqlalchemy)
 
-    enable_new_server = commands.add_parser("enable-new-server")
-    EnableNewServer.add_arguments(enable_new_server)
-
     # Initialize default values.
     arguments = parser.parse_args()
     if not hasattr(arguments, "command"):
